import { CommonModule } from '@angular/common';
import { Component, OnInit } from '@angular/core';
import { FormsModule } from '@angular/forms';
import * as Parse from 'parse';
import { NavComponent } from '../../../app/components/nav/nav.component';
import { AiChatService } from '../../../services/aichart.service';
import { HttpService } from '../../../services/http.service';
import {
  ionicStandaloneModules,
  ToastController,
} from '../../ionic-standalone.modules';
@Component({
  selector: 'app-withdrawal',
  templateUrl: './withdrawal.component.html',
  styleUrls: ['./withdrawal.component.scss'],
  standalone: true,
  imports: [...ionicStandaloneModules, NavComponent, CommonModule, FormsModule],
})
export class WithdrawalComponent implements OnInit {
  rate: number = 0.1; //提现手续费率
  service: number = 0; //提现手续费
  received_price: number = 0; //实际到账金额
  price: number = 0;

  income: {
    balance: number;
    used: number;
    total: number;
  } = {
    balance: 0,
    used: 0,
    total: 0,
  };

  bankInfo: {
    bankname: string;
    name: string;
    mobile: string;
    bankcard: string;
  } = {
    bankname: '',
    name: '',
    mobile: '',
    bankcard: '',
  };
  alipayInfo: {
    alipay: string;
    name: string;
  } = {
    alipay: '',
    name: '',
  };
  value: Number = 0;
  account?: Parse.Object;
  type: string = '银行卡'; //提现方式
  isOpenModal: boolean = false;
  constructor(
    private toastController: ToastController,
    private http: HttpService,
    private aiServ: AiChatService
  ) {}
  ngOnInit() {
    this.getAccount();
  }
  async getAccount() {
    let id = Parse.User.current()?.id;
    let query = new Parse.Query('Account');
    query.equalTo('user', id);
    query.equalTo('company', this.aiServ.company);
    this.account = await query.first();
    if (this.account?.get('bank')) {
      this.bankInfo = this.account?.get('bank')[0];
    }
    console.log(this.account);
    let anthorWallet = await this.aiServ.getAuthorWallet(id!);
    this.income = anthorWallet;
  }
  onChangeSex(e: any) {
    this.type = e.detail.value;
    console.log(this.type);
  }
  onChangePrice() {
    this.price = Math.round(this.price * 100) / 100;
  }
  openModal() {
    if (
      this.type == '支付宝' &&
      Object.values(this.alipayInfo).some(
        (item) => item == '' || item == undefined
      )
    ) {
      this.toast('请填写提现信息', 1500);
      return;
    } else if (
      this.type == '银行卡' &&
      Object.values(this.bankInfo).some(
        (item) => item == '' || item == undefined
      )
    ) {
      this.toast('请填写提现信息', 1500);
      return
    }
    if (this.price < 200) {
      this.toast('最低提现金额为200', 1500);
      return;
    }
    if (this.income.balance < this.price) {
      this.toast('申请提现金额不得超过可提现余额', 1500);
      return;
    }
    // this.service = Math.round(this.price * this.rate * 100) / 100;
    this.isOpenModal = true;
  }
  async confirm() {
    // if (!this.price || this.price < 0) {
    //   this.toast('请输入正确金额', 1500);
    //   return;
    // }
    let params = {
      uid: Parse.User.current()?.id,
      price: this.price,
      bankInfo: this.bankInfo,
    };
    let res = await this.http.httpRequst(
      'https://server.fmode.cn/api/ailiao/withdraw',
      params,
      'POST'
    );
    console.log(res);
    if (res.code == 200) {
      this.toast('申请成功', 1500, 'success');
    } else {
      this.toast(res.message, 1500);
      return
    }
    this.isOpenModal = false;
    history.back();
  }

  async toast(title: string, time: number, color?: string) {
    const toast = await this.toastController.create({
      message: title,
      color: color ?? 'warning',
      duration: time || 1500,
    });
    toast.present();
  }
}
